#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-CtQ9ahp1MKtIu8MwnDQrGb
key:                  floskell-0.10.8-CtQ9ahp1MKtIu8MwnDQrGb
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  5d34932c8dc4487b28f4eb9e89974a49
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-CtQ9ahp1MKtIu8MwnDQrGb
depends:
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx
    attoparsec-aeson-2.2.0.0-HG9CMQkMQvnCesXbjt6Tfp base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 haskell-src-exts-1.23.1-DJO7AhchdyKJXxsfsE4TT7
    monad-dijkstra-0.1.1.5-GZkMuoincXPEAnWroap1tx mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V
    utf8-string-1.0.2-Jktg7mszcNkI00pgM6b6il

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

